#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/delete_pweb_document.sh
#
SCRIPTNAME=`basename $0`
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`
SYSDATE=`date +%Y:%m:%d:%H:%M:%S`

show_title()
{
   echo Prospect User Pweb Document Delete Utility.
   echo ----------------------------------------------------------------------
   echo @(#) delete_pweb_document.sh
   echo @(#) 
   echo Copyright 2010 IBM Corp.
   echo ----------------------------------------------------------------------
   echo
}

usage() {
   show_title
   echo "USAGE: "
   echo
   echo "$SCRIPTNAME [-cpath <current_path> -name <document_name>] | [-file <filename>] | [-output <output_name>] | [-force] | [-h <script usage>] "
   echo
   echo "Where:"
   echo "-h | -help                 : Displays the help usage section. "
   echo "-c | -cpath <current_path> : (Optional) This is the current location of the document."
   echo "                                        Cannot be used with -file. "
   echo "-n | -name <document_name> : (Optional) This is the Document name to be moved. Cannot be used with -file. "
   echo "-f | -file <filename>      : (Optional) Name of the input file with records to be processed. "
   echo "                                        The file is a tab delimited file (one record per line). For e.g., "
   echo '                                        /Users/public/report_result\tReport_doc1' 
   echo "-o | -output <output_name> : (Mandatory) User must enter a log file name. "
   echo "-force                     : (Optional) When user enters -force user will not be prompted to confirm the Delete. "
   echo
   echo "Examples: "
   echo "a) Delete single document (without force option) " 
   echo "   delete_pweb_document.sh -c /Users/public/Folder_01 -n PageDoc -o /tmp/PageDoc.log "
   echo "b) Delete single document (with force option) " 
   echo "   delete_pweb_document.sh -c /Users/public/Folder_01 -n PageDoc -o /tmp/PageDoc.log -force "
   echo "c) Delete multiple documents (using file without force option) " 
   echo "   delete_pweb_document.sh -o /tmp/input_doc.log -f input_doc.list "
   echo "d) Delete multiple documents (using file with force option) " 
   echo "   delete_pweb_document.sh -o /tmp/input_doc.log -f input_doc.list -force "
   echo
}

# Parameter variables
pv_current_path=''
pv_document_name=''
pv_filename=''
pv_output_name=''
pv_force='N'

# local variables
lv_got_error=0
lv_end_status=0

if [ $# -eq 0 ]
then
    usage
    echo ""
    echo "Script usage Error"
    exit 2
fi

while [ $# -gt 0 ]
do
    case $1 in
        -c|-cpath)
            shift
            pv_current_path=$1
            ;;
        -n|-name)
            shift
            pv_document_name=$1
            ;;
        -f|-file)
            shift
            pv_filename=$1
            ;;
        -o|-output)
            shift
            pv_output_name=$1
            ;;
        -force)
            pv_force='Y'
            ;;
        -h|-help)
           usage
           exit 0
           ;;
        *)
            echo
            usage
            echo ""
            echo "$SCRIPTNAME: ERROR - Invalid parameter $1 !"
            echo "Script usage Error"
            exit 2
            ;;
    esac
    if [ $# -gt 0 ]
    then
       shift
    fi
done

log_into_db()
{
lv_component=$1
lv_log_msg=$2
sqlplus -s ${DB_CONNECT} <<EOF
  WHENEVER SQLERROR EXIT FAILURE
  set pagesize 800
  set linesize 150
  set verify off
  set heading off
  set showmode off
  set feedback off
  set serveroutput on size unlimited
  DECLARE
  BEGIN
     wm_log.log_message('$lv_component', '$lv_log_msg');
  EXCEPTION
      WHEN OTHERS THEN
           NULL;
  END;
/
  EXIT
EOF
}

getYesNo()
{
   while true
   do
     echo "WARNING!: This script will delete Pweb Document(s)"
     echo
     echo "Are you sure you wish to continue [y/n]? (default: n)  \c"
     read RESPONSE
     if [ ${RESPONSE:-n} = y ]
     then
        RESPONSE=y
        break
     fi
     if [ ${RESPONSE:-n} = n ]
     then
        RESPONSE=n
        break
     fi
   done
}

if [ ${pv_force} = 'N' ]
then
     getYesNo
elif [ ${pv_force} = 'Y' ]
then
     RESPONSE=y
fi

if [ ${RESPONSE} = y ]
then
   # Check mandatory arguments
   if [ ! "$pv_output_name" ] 
   then
       usage
       echo ""
       echo "$SCRIPTNAME: ERROR - Mandatory arguments not passed !"
       echo "Script usage Error"
       exit 2
   fi 

   DIRNAME=`dirname $pv_output_name`
   if [ ! -d "$DIRNAME" ]
   then
       usage
       echo ""
       echo "$SCRIPTNAME: ERROR - Output directory does not exist !"
       echo "Script usage Error"
       exit 2
   fi

   # Log file writable?
   > $pv_output_name
   if [ $? -ne 0 ]
   then
       usage
       echo ""
       echo "$SCRIPTNAME: ERROR - Cannot write to $pv_output_name !"
       echo "Script usage Error"
       exit 2
   fi

   # output passed args
   echo "" | tee -a $pv_output_name
   echo "Delete Process STARTED: $(date)" | tee -a $pv_output_name
   echo "" | tee -a $pv_output_name
   echo "Arguments passed:" | tee -a $pv_output_name
   echo "----------------" | tee -a $pv_output_name
   echo " Current path - "$pv_current_path | tee -a $pv_output_name
   echo " Document name - "$pv_document_name | tee -a $pv_output_name
   echo " Filename - "$pv_filename | tee -a $pv_output_name
   echo " Output name - "$pv_output_name | tee -a $pv_output_name
   echo | tee -a $pv_output_name

   if [ -n "$pv_filename" ]
   then
       if [[ -n "$pv_current_path" || -n "$pv_document_name" ]]
       then
          usage
          echo ""
          echo "$SCRIPTNAME: ERROR - Mismatch arguments used !"
          echo "Script usage Error"
          exit 2
       fi
   fi

   if [ -z "$pv_filename" ]
   then
       if [[ -z "$pv_current_path" || -z "$pv_document_name" ]]
       then
          usage
          echo ""
          echo "$SCRIPTNAME: ERROR - Mismatch arguments used !"
          echo "Script usage Error"
          exit 2
       fi
   fi

   lv_logspool=${pv_output_name}_$$
   lv_logtemp=${pv_output_name}_temp_$$

#---------------------------------------------------------------------------
# STARTUP
#---------------------------------------------------------------------------
#
(
echo "======================================================" 
echo "***"
echo "*** Delete Pweb Documents"
echo "***"
) | tee -a $pv_output_name

#---------------------------------------------------------------------------
# DELETE
#---------------------------------------------------------------------------
#
function int_delete_doc
{
sqlplus -s ${DB_CONNECT} <<EOF
  WHENEVER SQLERROR EXIT FAILURE
  set pagesize 800
  set linesize 150
  set verify off
  set heading off
  set showmode off
  set feedback off
  set serveroutput on size unlimited
  variable returnstatus number
  DECLARE
    vReturn INTEGER := 1;
  BEGIN
     vReturn := pe_MoveDelete_doc_api.delete_doc('$pv_current_path','$pv_document_name');

     IF (vReturn = 0) THEN
	COMMIT;
     ELSE
	ROLLBACK;
     END IF;

     :returnstatus := vReturn;
  EXCEPTION
      WHEN OTHERS THEN
           RAISE;
  END;
/
  EXIT :returnstatus
EOF

return $?
} 

echo "Deleting..." | tee -a $pv_output_name
if [[ -n "$pv_filename" && -e "$pv_filename" ]]
then
   log_into_db $SCRIPTNAME "Start deleting document(s) - "$SYSDATE
   doc_no=0
   while read doc_file
   do
     if [ ${#doc_file} -gt 0 ]
     then
        doc_no=$((doc_no+1))
        echo "$doc_file" | awk -F\t '{print $1}' | tr -d '"' | tr -d "'" | read pv_current_path
        echo "$doc_file" | awk -F\t '{print $2}' | tr -d '"' | tr -d "'" | read pv_document_name

        int_delete_doc > $lv_logspool
        if [ $? -ne 0 ]
        then
           lv_got_error=1
        fi
        cat $lv_logspool | tee -a $pv_output_name
     fi
   done < $pv_filename

   if [[ $lv_got_error -eq 1 ]]
   then
       lv_end_status=1
   fi

   log_into_db $SCRIPTNAME "End deleting document(s) - "$SYSDATE

   if [ $doc_no -eq 0 ]
   then
      echo "" | tee -a $pv_output_name
      echo "$SCRIPTNAME: ERROR - File does not contain any data !" | tee -a $pv_output_name 
      echo "Script Failed" | tee -a $pv_output_name
      exit 1
   fi
else
   log_into_db $SCRIPTNAME "Start deleting document(s) - "$SYSDATE
   int_delete_doc >> $lv_logspool
   if [ $? -ne 0 ]
   then
       lv_end_status=1
   fi
   cat $lv_logspool | tee -a $pv_output_name
   log_into_db $SCRIPTNAME "End deleting document(s) - "$SYSDATE
fi

rm $lv_log_temp 2>/dev/null
rm $lv_logspool 2>/dev/null
  
#---------------------------------------------------------------------------
# END PROCESS
#---------------------------------------------------------------------------
(
echo "======================================================"
echo ""
echo "Delete Process FINISHED: $(date)"
) | tee -a $pv_output_name

if [ $lv_end_status -eq 0 ]
then
   echo "" | tee -a $pv_output_name
   echo "Script completed successfully" | tee -a $pv_output_name
   exit 0
else
   echo "" | tee -a $pv_output_name 
   if [ $lv_got_error -eq 1 ]
   then
      echo "One or more records failed to delete, see log $pv_output_name for more information." | tee -a $pv_output_name
   fi
   echo "Script Failed" | tee -a $pv_output_name
   exit 1
fi

else
    echo "User entered \"n\". Terminating. No documents will be deleted."
fi

