#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2011. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/delete_busy_hour.sh
#
SCRIPTNAME=`basename $0`
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

show_title()
{
   echo
   echo Prospect User Soft Alarm Document Delete Utility.
   echo ----------------------------------------------------------------------
   echo @(#) delete_soft_alarm.sh
   echo @(#) 
   echo Copyright 2010 IBM Corp.
   echo ----------------------------------------------------------------------
}

usage() {
   show_title
   echo "USAGE: "
   echo "${SCRIPTNAME} [-type <Schedule | Group | Definition | Template> -cpath <cpath> -name <name>] | "
   echo "              [-depcheck <yes | no>] | [-file <filename>] | -output <output_log> | [-force] | [-h <usage>] "
   echo
   echo "-h	: Displays the help usage section. "
   echo "-type	: (Optional) This can be one of the following: "
   echo "                  - Schedule "
   echo "                  - Group "
   echo "                  - Definition "   
   echo "                  - Template "   
   echo "-cpath	: (Optional) This is the current location of the document. Cannot be used with -file. "
   echo "		     Use single quote (') to allow for spaces in the path "
   echo "-name	: (Optional) Document name. Cannot be used with -file. "
   echo "		     Use single quote (') to allow for spaces in the document name "
   echo "-file	: (Optional) Name of the input file with records to be processed. "
   echo "		     The file is a tab delimited file (one record per line). For e.g., "
   echo "                    Schedule	/Schedule/	Sa_schedule1 "
   echo "-output: (Mandatory) User must enter a log file name. "
   echo "-force : (Optional) When user enters -force user will not be prompted to confirm the Delete. "
   echo "-skipdepcheck : (Optional) When user enters -depcheck, dependencies check will be skiped while delete SA Definition" #alm00220470
   echo
   echo "Example: Delete Single Soft Alarm Document "
   echo "${SCRIPTNAME} -type Schedule -cpath /schedule/ -name Sa_schedule1 -output /tmp/delete_soft_alarm.log -depcheck -force "
   echo
   echo "Example: Delete Multiple Soft Alarm Document in input file "
   echo "${SCRIPTNAME} -file soft_alarm.lst -output /tmp/delete_soft_alarm.log -depcheck -force"
   echo
   exit 2
}

pv_type=''
pv_cpath=''
pv_name=''
pv_file=''
pv_output=''
pv_depcheck='0' #alm00220470
pv_force='0'
scriptStatus='0'
scriptError='0'

#Display usage if no arguments passed
if [ $# -eq 0 ]
then
   usage
fi

#Parse arguments
while [ $# -gt 0 ]
do
    case $1 in
	  -type)
	    shift
	    pv_type=$1
	    ;;
	  -cpath)
	    shift
	    pv_cpath=$1
	    ;;
	  -name)
	    shift
	    pv_name=$1
	    ;;
	  -file)
	    shift
	    pv_file=$1
	    ;;
	  -output)
	    shift
	    pv_output=$1
	    ;;
	  -skipdepcheck) #alm00220470
        pv_depcheck=1
        ;;		
	  -force)
	    pv_force=1
	    ;;
	  -h|-help)
	    usage
	    ;;
	  *)
	    echo "${SCRIPTNAME}: Invalid parameter $1 "
	    usage
    esac
     
     if [ $# -gt 0 ]
     then
          shift
     fi

done

checkforce()
{
if [ "$pv_force" != "1" ]
then 
   echo ""
   echo "WARNING!: Delete Soft Alarm Document(s)"
   echo "Are you sure want to Delete [y/n] : \c "  
   read answer 
   
   if [ -z "$answer" ]
   then
      echo "Terminating. No soft alarm document will be deleted"
      exit 1
   fi
   
   if [ "$answer" != 'y' ] && [ "$answer" != 'Y' ] 
   then
      echo "Terminating. No soft alarm document will be deleted"
      exit 1
   fi
   
 fi     
}

#alm00220470
depcheck()
{
if [ "$pv_depcheck" = "1" ]
then
	if [[ "$pv_type" != "Definition" && "$pv_type" != "definition" ]]
	then
	    echo
		echo "e{SCRIPTNAME}: -skipdepcheck must be used with -type Definition "
		usage
		exit 1
	fi	
fi
}

function runplsqlproc
{
sqlplus -s ${DB_CONNECT} <<SQLPLUS
WHENEVER SQLERROR EXIT FAILURE
  set pagesize 800
  set linesize 150
  set verify off
  set heading off
  set showmode off
  set feedback off
  set serveroutput on size unlimited
variable returnstatus number

DECLARE

lv_type	varchar2(10);
lv_status number;
BEGIN
   
	lv_type:= upper(${pv_type});

	if lv_type = 'SCHEDULE' then
		SA_Delete.delete_sa_schedule($pv_cpath, $pv_name,lv_status);
	elsif lv_type = 'GROUP' then	
		SA_Delete.delete_sa_group($pv_cpath, $pv_name,lv_status);
	elsif lv_type = 'DEFINITION' then	
		SA_Delete.delete_sa_definition($pv_cpath, $pv_name, $pv_depcheck, lv_status);
	elsif lv_type = 'TEMPLATE' then	
		SA_Delete.delete_sa_template($pv_cpath, $pv_name,lv_status);		
	end if;
   
	if lv_status = 0 then
		COMMIT;
		wm_log.log_message('$SCRIPTNAME', 'Soft Alarm '||lv_type||' '||$pv_name||' Deleted');
		:returnstatus := 0;
	else
		ROLLBACK;
		wm_log.log_message('$SCRIPTNAME', 'Soft Alarm '||lv_type||' '||$pv_name||' Delete FAILED');
		:returnstatus := 1;
	end if;	
   
	
EXCEPTION
	WHEN OTHERS THEN
	ROLLBACK;
	wm_log.log_message('$SCRIPTNAME', 'Soft Alarm '||lv_type||' '||$pv_name||' Delete FAILED');
	:returnstatus := 1;
	RAISE;
END;
/
EXIT :returnstatus
SQLPLUS
}

log_into_db()
{
lv_component=$1
lv_log_msg=$2
sqlplus -s ${DB_CONNECT} <<EOF
  WHENEVER SQLERROR EXIT FAILURE
  set pagesize 800
  set linesize 150
  set verify off
  set heading off
  set showmode off
  set feedback off
  set serveroutput on size unlimited
  DECLARE
  BEGIN
     wm_log.log_message('$lv_component', '$lv_log_msg');
  EXCEPTION
      WHEN OTHERS THEN
           NULL;
  END;
/
  EXIT
EOF
}
#Check mandotary arguments
if [[ -z "$pv_type" || -z "$pv_cpath" || -z "$pv_name" ]]
then
     if [[ -z "$pv_file" ]]
     then
      echo
	  echo "${SCRIPTNAME}: -type/-cpath/-name or -file argument not passed" >&2
          usage
          exit 1
     fi
fi

#Check -type is valid
if [[ -n "$pv_type" && -z "$pv_file" ]]
then
	if [[ "$pv_type" != "SCHEDULE" && "$pv_type" != "Schedule" && "$pv_type" != "schedule" &&
		  "$pv_type" != "GROUP" && "$pv_type" != "Group" && "$pv_type" != "group" &&
		  "$pv_type" != "DEFINITION" && "$pv_type" != "Definition" && "$pv_type" != "definition" &&
		  "$pv_type" != "TEMPLATE" && "$pv_type" != "Template" && "$pv_type" != "template" ]]
	then
		 echo
		 echo "${SCRIPTNAME}: -type must be <Schedule | Group | Definition | Template> "
		 usage
		 exit 1
	fi
	
	#alm00220470
	depcheck

fi	


	
#Check -file argument constraints
if [[ -n "$pv_file" ]]
then
     if [[ -n "$pv_type" || -n "$pv_cpath" || -n "$pv_name" ]]
     then
          echo
	  echo "${SCRIPTNAME}: -file cannot be used with -type/-cpath/-name arguments " >&2
	  usage
	  exit 1
     fi
fi

#Check Mandotary -output argument
if [ ! "$pv_output" ] 
then
     echo
     echo "${SCRIPTNAME}: Mandatory -output arguments not passed !" >&2
     usage
     exit 1
fi 

#Check dir/path is valid
DIRNAME=`dirname ${pv_output}`
if [[ ! -d ${DIRNAME} ]]
then
     echo
     echo "${SCRIPTNAME}: Invalid output path"
     exit 1
fi

#Check Log file writable
> $pv_output
if [ $? -ne 0 ]
then
	 echo
	 echo "${SCRIPTNAME}: Cannot write to $pv_output" >&2
	 exit 1
fi

#Check input file
if [[ "$pv_file" != "" ]]
then
   ###check if file exists
   if [[ ! -a "$pv_file" ]] 
   then 
     echo
     echo "${SCRIPTNAME}: ${pv_file} does not exist"
     exit 1
   fi
   ###check if file size > zero
   if [[ ! -s "$pv_file" ]] 
   then 
     echo
     echo "${SCRIPTNAME}: ${pv_file} does not contain any data"
     exit 1
   fi   
fi

#Check if -force argurment pass else prompt message before delete
checkforce

#Start spooling log file
(
echo ""
echo "Delete Soft Alarm Process STARTED: $(date)"
echo "${SCRIPTNAME} Arguments passed:"

if [[ -n "$pv_type" && -n "$pv_cpath" && -n "$pv_name" ]]
then 
     echo "Document type - ${pv_type}"
     echo "Current Path - ${pv_cpath}"
	 echo "Document name - ${pv_name}"
fi

if [ -n "$pv_file" ]
then
     echo "Filename - ${pv_file}"
fi

echo "Output name - ${pv_output}"
echo ""

#---------------------------------------------------------------------------
# STARTUP
#---------------------------------------------------------------------------
#
echo "==================================================================================" 
echo "***"
echo "*** Delete Soft Alarm Documents"
echo "***"

#---------------------------------------------------------------------------
# DELETE
#---------------------------------------------------------------------------
#
echo ""
echo "Deleting..."
echo ""

if [[ -n "$pv_file" && -e "$pv_file" ]]
then
   log_into_db $SCRIPTNAME "Start deleting soft alarm"
   doc_no=0
   while read doc_file
   do
     doc_no=$((doc_no+1))
     isScriptErr=0; 
     echo "$doc_file" | awk '{print $1}' | read pv_type
     echo "$doc_file" | awk 'BEGIN {FS="\t";}{print $2}' | read pv_cpath
	 echo "$doc_file" | awk 'BEGIN {FS="\t";}{print $3}' | read pv_name
	
     pv_type="'"$pv_type"'"	
	 pv_cpath="'"$pv_cpath"'"
     pv_name="'"$pv_name"'"
     
     runplsqlproc
	 scriptStatus=$? 
	 if [ ${scriptStatus} -ne 0 ]
	 then
		scriptError=1;
	 fi
   done < $pv_file

   log_into_db $SCRIPTNAME "End deleting soft alarm"
   if [ "$doc_no" -eq 0 ]
   then
      echo | tee -a $pv_output
      echo "${SCRIPTNAME}: File does not contain any data !" >$2 
      exit 1
   fi
else
     pv_type="'"$pv_type"'"	
	 pv_cpath="'"$pv_cpath"'"
     pv_name="'"$pv_name"'"
	 
     log_into_db $SCRIPTNAME "Start deleting soft alarm"
     runplsqlproc
	 scriptStatus=$? 
	 if [ ${scriptStatus} -ne 0 ]
	 then
		scriptError=1;
	 fi
     log_into_db $SCRIPTNAME "End deleting soft alarm"
fi

#---------------------------------------------------------------------------
# END PROCESS
#---------------------------------------------------------------------------
echo "=================================================================================="
echo "Delete Process FINISHED: $(date)"
echo ""

if [ "$scriptError" != "0" ]
then
	echo "Script completed with ERRORS, refer log file for more information: : ${pv_output}" 
	echo ""
	exit 1
else	
    echo "Script Completed Successfully "
	echo ""
	exit 0
fi
)  | tee -a $pv_output